@@ -135,8 +135,7 @@ class Kernel(object):
             raise RuntimeError("Can't run a kernel that's been shut down or crashed. Create a new kernel.")
 
         coro = meta.instantiate_coroutine(corofunc, *args) if corofunc else None
-
-        with meta.running():
+        with meta.running(self):
             # Make the kernel runtime environment (if needed)
             if not self._runner:
                 self._runner = self._make_kernel_runtime()
@@ -754,7 +753,7 @@ class Kernel(object):
                                 active.exception = e
                                 if (active != main_task and not isinstance(e, (CancelledError, SystemExit))):
                                     log.error('Task Crash: %r', active, exc_info=True)
-                                if not isinstance(e, Exception):
+                                if not isinstance(e, (Exception, CancelledError)):
                                     raise
                             break
 
